@@ -32,7 +32,7 @@ $PACMAN --noconfirm -S ${XPKG}python ${XPKG}libnotify
 #media libraries (more than we actually need):
 $PACMAN --noconfirm -S ${XPKG}ffmpeg ${XPKG}libyuv-git ${XPKG}gst-plugins-good ${XPKG}gst-plugins-bad ${XPKG}gst-plugins-ugly
 #network layer libraries:
-$PACMAN --noconfirm -S ${XPKG}lz4 ${XPKG}lzo2 heimdal-libs openssh sshpass ${XPKG}libsodium ${XPKG}qrencode
+$PACMAN --noconfirm -S ${XPKG}lz4 ${XPKG}lzo2 heimdal-libs openssh sshpass ${XPKG}libsodium ${XPKG}qrencode ${XPKG}pinentry
 #python GStreamer bindings:
 $PACMAN --noconfirm -S ${XPKG}gst-python
 #development tools and libs for building extra packages:
@@ -63,3 +63,7 @@ echo "https://github.com/jgm/pandoc/releases/latest"
 echo
 echo "for a more seamless theme, install https://b00merang.weebly.com/windows-10.html"
 echo " (see ticket #2762)"
+echo
+echo "to support NVIDIA hardware accelerated encoders NVENC and NVJPEG,"
+echo "install their headers and libraries"
+echo "then create a pkgconfig file so the build system will detect them"
