@@ -290,7 +290,7 @@ rsync -rpl ${JHBUILD_PREFIX}/share/icons/Adwaita ${RSCDIR}/share/icons/
 echo " * move GTK css"
 mv ${RSCDIR}/share/xpra/css ${RSCDIR}/
 #unused py2app scripts:
-rm ${RSCDIR}/__boot__.py ${RSCDIR}/__error__.sh ${RSCDIR}/client_launcher.py
+rm ${RSCDIR}/__boot__.py ${RSCDIR}/__error__.sh
 
 
 if [ "$STRIP_SOURCE" == "1" ]; then
@@ -313,7 +313,7 @@ ln -sf Resources/lib Frameworks
 pushd Resources/lib
 if [ "$STRIP_GSTREAMER_PLUGINS" == "1" ]; then
 	echo "removing extra gstreamer dylib deps:"
-	for x in basevideo cdda check netbuffer photography rtsp sdp signalprocessor; do
+	for x in check photography rtsp sdp; do
 		echo "* removing "$x
 		rm libgst${x}*
 	done
@@ -324,7 +324,7 @@ GST_PLUGIN_DIR="./gstreamer-1.0"
 if [ "$STRIP_GSTREAMER_PLUGINS" == "1" ]; then
 	KEEP="./gstreamer-1.0.keep"
 	mkdir ${KEEP}
-	PLUGINS="app audio coreelements faac faad flac oss osxaudio speex volume vorbis wav lame mad opus ogg gdp isomp4 matroska"
+	PLUGINS="app audio coreelements faac faad flac oss osxaudio speex volume vorbis wav lame opus ogg gdp isomp4 matroska"
 	for x in $PLUGINS; do
 		echo "* keeping "$x
 		mv ${GST_PLUGIN_DIR}/libgst${x}* ${KEEP}/
@@ -340,8 +340,8 @@ popd	#"Resources/lib"
 echo
 echo "*******************************************************************************"
 echo "Add the manual in HTML format (since we cannot install the man page properly..)"
-groff -mandoc -Thtml < ../../man/xpra.1 > ${RSCDIR}/share/manual.html
-groff -mandoc -Thtml < ../../man/xpra_launcher.1 > ${RSCDIR}/share/launcher-manual.html
+groff -mandoc -Thtml < ../../fs/share/man/man1/xpra.1 > ${RSCDIR}/share/manual.html
+groff -mandoc -Thtml < ../../fs/share/man/man1/xpra_launcher.1 > ${RSCDIR}/share/launcher-manual.html
 
 if [ "${CLIENT_ONLY}" != "1" ]; then
 	echo "Add the HTML5 client"
