@@ -1,15 +1,15 @@
 BUILD_BIT='64bit'
 BUILD_CPU='x86_64'
-BUILD_DATE='2021-05-21'
+BUILD_DATE='2021-07-11'
 BUILD_MACHINE='x86_64'
-BUILD_OS='Linux Fedora 34 ThirtyFour'
-BUILD_TIME='10:48'
+BUILD_OS='linux'
+BUILD_TIME='11:14'
 BUILT_BY='antoine'
 BUILT_ON='localhost.localdomain'
-COMPILER_VERSION='gcc (GCC) 11.1.1 20210428 (Red Hat 11.1.1-1)'
+COMPILER_VERSION='gcc (GCC) 11.1.1 20210531 (Red Hat 11.1.1-3)'
 CYTHON_VERSION='0.29.21'
 LINKER_VERSION='GNU ld version 2.35.1-41.fc34'
-PYTHON_VERSION='3.9.5'
+PYTHON_VERSION='3.9.6'
 RELEASE_BUILD=True
 lib_gobject_introspection='1.68.0'
 lib_gtk='3.24.29'
