@@ -868,6 +868,8 @@ class XpraClientBase(ServerInfoMixin, FilePrintMixin):
         conn = self._protocol._conn
         keydata = parse_encoded_bin_data(conn.options.get("keydata", None))
         cryptolog("get_encryption_key() connection options keydata=%s", ellipsizer(keydata))
+        if keydata:
+            return keydata
         keyfile = conn.options.get("encryption-keyfile") or conn.options.get("keyfile") or self.encryption_keyfile
         if keyfile:
             if os.path.exists(keyfile):
@@ -882,7 +884,7 @@ class XpraClientBase(ServerInfoMixin, FilePrintMixin):
                   len(key or ""), XPRA_ENCRYPTION_KEY)
         if key:
             return key.strip(b"\n\r")
-        raise InitExit(1, "no encryption key")
+        raise InitExit(EXIT_ENCRYPTION, "no encryption key")
 
     def _process_hello(self, packet):
         self.remove_packet_handlers("challenge")
