@@ -786,6 +786,11 @@ class ClientWindowBase(ClientWidgetBase):
                ("SPLASH" in window_types)
 
 
+    def _focus(self):
+        focuslog("_focus() wid=%s, focused=%s", self._id, self._client._focused)
+        if self._client._focused!=self._id:
+            self._client.update_focus(self._id, True)
+
     def _unfocus(self):
         focuslog("_unfocus() wid=%s, focused=%s", self._id, self._client._focused)
         if self._client._focused==self._id:
