@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # This file is part of Xpra.
 # Copyright (C) 2009-2020 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
@@ -322,13 +322,13 @@ class ApplicationWindow:
         self.username_entry.set_width_chars(16)
         self.username_entry.connect("changed", self.validate)
         self.username_entry.connect("activate", self.connect_clicked)
-        self.username_entry.set_tooltip_text("username")
+        self.username_entry.set_tooltip_text("server username")
         self.host_entry = Gtk.Entry()
         self.host_entry.set_max_length(128)
         self.host_entry.set_width_chars(24)
         self.host_entry.connect("changed", self.validate)
         self.host_entry.connect("activate", self.connect_clicked)
-        self.host_entry.set_tooltip_text("hostname")
+        self.host_entry.set_tooltip_text("server hostname or IP address")
         self.ssh_port_entry = Gtk.Entry()
         self.ssh_port_entry.set_max_length(5)
         self.ssh_port_entry.set_width_chars(5)
