@@ -19,7 +19,7 @@ from xpra.child_reaper import reaper_cleanup
 from xpra.platform.info import get_sys_info
 from xpra.os_util import (
     platform_name, bytestostr, strtobytes,
-    BITS, POSIX, is_Wayland,
+    BITS, POSIX, WIN32, OSX, is_Wayland,
     get_frame_info, get_info_env, get_sysconfig_info,
     )
 from xpra.util import (
@@ -27,6 +27,7 @@ from xpra.util import (
     merge_dicts,
     XPRA_AUDIO_NOTIFICATION_ID, XPRA_DISCONNECT_NOTIFICATION_ID,
     )
+from xpra.scripts.config import parse_bool
 from xpra.exit_codes import EXIT_CONNECTION_FAILED, EXIT_OK, EXIT_CONNECTION_LOST
 from xpra.version_util import get_version_info_full, get_platform_info
 from xpra.client import mixin_features
@@ -168,13 +169,14 @@ class UIXpraClient(ClientBaseClass):
 
     def init(self, opts):
         """ initialize variables from configuration """
+        self.init_aliases()
         for c in CLIENT_BASES:
             log("init: %s", c)
             c.init(self, opts)
 
         self.title = opts.title
         self.session_name = bytestostr(opts.session_name)
-        self.xsettings_enabled = opts.xsettings
+        self.xsettings_enabled = not (OSX or WIN32) and parse_bool("xsettings", opts.xsettings, True)
         self.readonly = opts.readonly
         self.client_supports_sharing = opts.sharing is True
         self.client_lock = opts.lock is True
@@ -219,19 +221,18 @@ class UIXpraClient(ClientBaseClass):
 
         if MOUSE_DELAY_AUTO:
             try:
-                v = self.get_vrefresh()
-                if v<=0:
-                    #some platforms don't detect the vrefresh correctly
-                    #(ie: macos in virtualbox?), so use a sane default:
-                    v = 60
-                self._mouse_position_delay = 1000//v//2
+                #some platforms don't detect the vrefresh correctly
+                #(ie: macos in virtualbox?), so use a sane default minimum
+                #discount by 5ms to ensure we have time to hit the target
+                v = max(60, self.get_vrefresh())
+                self._mouse_position_delay = max(5, 1000//v//2 - 5)
                 log("mouse delay: %s", self._mouse_position_delay)
             except Exception:
                 log("failed to calculate automatic delay", exc_info=True)
 
     def get_vrefresh(self):
         #this method is overriden in the GTK client
-        from xpra.platform.gui import get_vrefresh
+        from xpra.platform.gui import get_vrefresh  #pylint: disable=import-outside-toplevel
         return get_vrefresh()
 
 
@@ -242,7 +243,7 @@ class UIXpraClient(ClientBaseClass):
             c.run(self)
 
 
-    def quit(self, _exit_code=0):
+    def quit(self, exit_code=0):
         raise NotImplementedError()
 
     def cleanup(self):
