@@ -55,6 +55,8 @@ CLOSED_EXCEPTIONS = ()
 def can_retry(e):
     if isinstance(e, socket.timeout):
         return "socket.timeout"
+    if isinstance(e, BlockingIOError):
+        return True
     if isinstance(e, BrokenPipeError):
         raise ConnectionClosedException(e) from None
     if isinstance(e, OSError):
@@ -416,19 +418,23 @@ class SocketConnection(Connection):
             if fd:
                 info["fileno"] = fd
             #ie: self.local = ("192.168.1.7", "14500")
+            log("do_get_socket_info(%s) fd=%s, local=%s", fd, self.local)
             if self.local and len(self.local)==2:
                 from xpra.net.net_util import get_interface
                 iface = get_interface(self.local[0])
                 #ie: iface = "eth0"
+                device_info = {}
+                if iface:
+                    device_info["name"] = iface
                 if iface and iface!="lo":
                     try:
                         from xpra.platform.netdev_query import get_interface_info
                     except ImportError as e:
                         log("do_get_socket_info() no netdev_query: %s", e)
                     else:
-                        i = get_interface_info(fd, iface)
-                        if i:
-                            info["device"] = i
+                        device_info.update(get_interface_info(fd, iface))
+                if device_info:
+                    info["device"] = device_info
         except (OSError, ValueError) as e:
             log("do_get_socket_info() error querying socket speed", exc_info=True)
             log.error("Error querying socket speed:")
