@@ -184,7 +184,7 @@ def detect_xvfb_command(conf_dir="/etc/xpra/", bin_dir=None,
     return Xorg_suid_check()
 
 
-def xvfb_cmd_str(xvfb):
+def xvfb_cmd_str(xvfb, wrap=False):
     xvfb_str = ""
     while xvfb:
         s = ""
@@ -201,7 +201,10 @@ def xvfb_cmd_str(xvfb):
             else:
                 s += " "+v
         if xvfb_str:
-            xvfb_str += " \\\n    "
+            if wrap:
+                xvfb_str += " \\\n    "
+            else:
+                xvfb_str += " "
         xvfb_str += s
     return xvfb_str
 
@@ -596,7 +599,7 @@ OPTION_TYPES = {
                     "attach"            : bool,
                     "use-display"       : str,
                     "fake-xinerama"     : str,
-                    "resize_display"    : str,
+                    "resize-display"    : str,
                     "tray"              : bool,
                     "pulseaudio"        : bool,
                     "dbus-proxy"        : bool,
@@ -743,7 +746,9 @@ CLIENT_OPTIONS = ["title", "username", "password", "session-name",
                   "env"]
 
 CLIENT_ONLY_OPTIONS = ["username", "swap-keys", "dock-icon",
-                       "tray", "delay-tray", "tray-icon"]
+                       "tray", "delay-tray", "tray-icon",
+                       "attach",
+                       ]
 
 #options that clients can pass to the proxy
 #and which will be forwarded to the new proxy instance process:
@@ -762,7 +767,7 @@ PROXY_START_OVERRIDABLE_OPTIONS = [
     "microphone", "speaker", "sound-source", "pulseaudio",
     "idle-timeout", "server-idle-timeout",
     "use-display",
-    "fake-xinerama", "resize_display", "dpi", "pixel-depth",
+    "fake-xinerama", "resize-display", "dpi", "pixel-depth",
     "readonly", "keyboard-sync", "cursors", "bell", "notifications", "xsettings",
     "system-tray", "sharing", "lock", "windows", "webcam", "html", "http-scripts",
     "terminate-children", "exit-with-children", "exit-with-client",
