@@ -11,6 +11,7 @@ import os
 from xpra.os_util import bytestostr, strtobytes, hexstr
 from xpra.util import typedict, envbool, iround
 from xpra.gtk_common.error import xswallow, xsync, xlog
+from xpra.scripts.config import parse_bool
 from xpra.x11.x11_server_core import X11ServerCore, XTestPointerDevice
 from xpra.x11.bindings.keyboard_bindings import X11KeyboardBindings #@UnresolvedImport
 from xpra.x11.xsettings_prop import XSettingsTypeInteger, XSettingsTypeString, BLACKLISTED_XSETTINGS
@@ -50,9 +51,8 @@ class X11ServerBase(X11ServerCore):
         (see XpraServer or DesktopServer for actual implementations)
     """
 
-    def __init__(self, clobber):
-        self.clobber = clobber
-        X11ServerCore.__init__(self)
+    def __init__(self):
+        super().__init__()
         self._default_xsettings = {}
         self._settings = {}
         self.double_click_time = 0
@@ -66,21 +66,28 @@ class X11ServerBase(X11ServerCore):
 
     def do_init(self, opts):
         super().do_init(opts)
-        self._xsettings_enabled = opts.xsettings
+        #the server class sets the default value for 'xsettings_enabled'
+        #it is overriden in the seamless server (enabled by default),
+        #and we let the options have the final say here:
+        self._xsettings_enabled = parse_bool("xsettings", opts.xsettings, self._xsettings_enabled)
+        log("xsettings_enabled(%s)=%s", opts.xsettings, self._xsettings_enabled)
         if self._xsettings_enabled:
             from xpra.x11.xsettings import XSettingsHelper
             self._default_xsettings = XSettingsHelper().get_settings()
             log("_default_xsettings=%s", self._default_xsettings)
             self.init_all_server_settings()
 
+    def save_pid(self):
+        from xpra.scripts.server import _save_int
+        _save_int(b"XPRA_SERVER_gPID", os.getpid())
 
     def init_display_pid(self, pid):
         if pid:
             from xpra.scripts.server import _save_int
-            _save_int(b"_XPRA_SERVER_PID", pid)
+            _save_int(b"XPRA_XVFB_PID", pid)
         else:
             from xpra.scripts.server import _get_int
-            pid = _get_int(b"_XPRA_SERVER_PID")
+            pid = _get_int(b"XPRA_XVFB_PID") or _get_int(b"_XPRA_SERVER_PID")
             if not pid:
                 log.info("xvfb pid not found")
             else:
@@ -113,33 +120,15 @@ class X11ServerBase(X11ServerCore):
 
 
     def init_dbus(self, dbus_pid, dbus_env):
-        try:
-            from xpra.server.dbus import dbus_start
-            assert dbus_start
-        except ImportError as e:
-            log("init_dbus(%s, %s)", dbus_pid, dbus_env, exc_info=True)
-            log.warn("Warning: cannot initialize dbus")
-            log.warn(" %s", e)
-            return
-        from xpra.server.dbus.dbus_start import (
-            get_saved_dbus_pid, get_saved_dbus_env,
-            save_dbus_pid, save_dbus_env,
-            )
-        super().init_dbus(dbus_pid, dbus_env)
-        if self.clobber:
-            #get the saved pids and env
-            self.dbus_pid = get_saved_dbus_pid()
-            self.dbus_env = get_saved_dbus_env()
-            dbuslog("retrieved existing dbus attributes: %s, %s", self.dbus_pid, self.dbus_env)
-            if self.dbus_env:
-                os.environ.update(self.dbus_env)
-        else:
+        dbuslog("init_dbus(%s, %s)", dbus_pid, dbus_env)
+        if dbus_pid and dbus_env:
+            os.environ.update(dbus_env)
+            self.dbus_pid = dbus_pid
+            self.dbus_env = dbus_env
             #now we can save values on the display
             #(we cannot access gtk3 until dbus has started up)
-            if self.dbus_pid:
-                save_dbus_pid(self.dbus_pid)
-            if self.dbus_env:
-                save_dbus_env(self.dbus_env)
+            from xpra.server.dbus.dbus_start import save_dbus_env
+            save_dbus_env(dbus_env)
 
 
     def last_client_exited(self):
